The highest tagged major version is
v3.
package
Version:
v1.9.36
Opens a new window with list of versions in this module.
Published: Sep 10, 2023
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
define handler
func (Handler) Get ¶
Get get user list
get /
route: GET / > main.Handler.Get
func (Handler) GetParam ¶
added in
v1.9.32
GetParam get some param
get param id planA
@param: uid.UID userId
route: GET /:param > main.Handler.GetDetailParam
func (Handler) Put ¶
added in
v1.9.32
Put create user
put /
{
"user": "username",
"password": "password"
}
route: PUT / > main.Handler.Put
Source Files
¶
Click to show internal directories.
Click to hide internal directories.